@@ -49,6 +49,7 @@ gnome_vfs_open (GnomeVFSHandle **handle,
 	GnomeVFSResult result;
 
 	g_return_val_if_fail (handle != NULL, GNOME_VFS_ERROR_BAD_PARAMETERS);
+	*handle = NULL;
 	g_return_val_if_fail (text_uri != NULL, GNOME_VFS_ERROR_BAD_PARAMETERS);
 
 	uri = gnome_vfs_uri_new (text_uri);
@@ -109,6 +110,7 @@ gnome_vfs_create (GnomeVFSHandle **handle,
 	GnomeVFSResult result;
 
 	g_return_val_if_fail (handle != NULL, GNOME_VFS_ERROR_BAD_PARAMETERS);
+	*handle = NULL;
 	g_return_val_if_fail (text_uri != NULL, GNOME_VFS_ERROR_BAD_PARAMETERS);
 
 	uri = gnome_vfs_uri_new (text_uri);
@@ -692,9 +694,17 @@ gnome_vfs_check_same_fs (const gchar *source,
  * @uri: a uri.
  * @info: information that must be set for the file.
  * @mask: bit mask representing which fields of @info need to be set.
- * 
+ *
  * Set file information for @uri; only the information for which the
  * corresponding bit in @mask is set is actually modified.
+ *
+ * <note>
+ * @info's %valid_fields is not required to contain the
+ * #GnomeVFSFileInfoFields corresponding to the specified 
+ * #GnomeVFSSetFileInfoMask fields of @mask. It
+ * is assumed that the @info fields referenced by @mask
+ * are valid.
+ * </note>
  * 
  * Return value: an integer representing the result of the operation.
  */
@@ -714,6 +724,14 @@ gnome_vfs_set_file_info_uri (GnomeVFSURI *uri,
  * 
  * Set file information for @uri; only the information for which the
  * corresponding bit in @mask is set is actually modified.
+ *
+ * <note>
+ * @info's %valid_fields is not required to contain the
+ * #GnomeVFSFileInfoFields corresponding to the specified 
+ * #GnomeVFSSetFileInfoMask fields of @mask. It
+ * is assumed that the @info fields referenced by @mask
+ * are valid.
+ * </note>
  * 
  * Return value: an integer representing the result of the operation.
  */
@@ -778,9 +796,13 @@ gnome_vfs_monitor_add (GnomeVFSMonitorHandle **handle,
                        GnomeVFSMonitorCallback callback,
                        gpointer user_data)
 {
-	GnomeVFSURI *uri = gnome_vfs_uri_new (text_uri);
+	GnomeVFSURI *uri;
 	GnomeVFSResult result;
 
+	g_return_val_if_fail (handle != NULL, GNOME_VFS_ERROR_BAD_PARAMETERS);
+	*handle = NULL;
+	g_return_val_if_fail (text_uri != NULL, GNOME_VFS_ERROR_BAD_PARAMETERS);
+	uri = gnome_vfs_uri_new (text_uri);
 	if (uri == NULL) {
 		return GNOME_VFS_ERROR_INVALID_URI;
 	}
